@@ -1,17 +1,15 @@
 from .build import BuildCommand
 from .check import CheckCommand
 from .command import Command
-from .ppa import PPACommand
 from .root import RootCommand
-from .s3_repo import S3RepoCommand
 from .source import SourceCommand
+from .upload import UploadCommand
 
 __all__ = [
     "Command",
     "RootCommand",
     "SourceCommand",
-    "S3RepoCommand",
     "BuildCommand",
     "CheckCommand",
-    "PPACommand",
+    "UploadCommand",
 ]
